@@ -5,7 +5,7 @@ import sys
 import traceback
 
 import dbus
-import dbus.mainloop.glib
+import dbus.mainloop.qt
 import alarm
 #import timer
 import os
@@ -57,14 +57,15 @@ class MyForm(QtGui.QMainWindow):
         QtCore.QObject.connect(self.ui.actionMenuTips, QtCore.SIGNAL('triggered()'), self.showTips)
         QtCore.QObject.connect(self.ui.actionMenuEdit, QtCore.SIGNAL('triggered()'), self.edit_dialog)
 
-        dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
+        dbus.mainloop.qt.DBusQtMainLoop(set_as_default=True)
         bus = dbus.SystemBus()
         # get Current registered Cell ID
         dbus_object = bus.get_object('com.nokia.phone.net', '/com/nokia/phone/net')
         cellinfo = dbus.Interface(dbus_object, 'Phone.Net')
 #        cell_signal_handler(cellinfo.get_registration_status())
-        #cellinfo.get_registration_status()[2]
-        #cellinfo.get_selected_radio_access_technology()
+
+        if int(cellinfo.get_selected_radio_access_technology()[0]) != 1:
+            QtGui.QMessageBox.information(self, "3G networks are allowed in settings", "Please use 2G-only (GSM) networks to ensure stable behaviour. Go to Settings > Phone > Network mode to change it.")
         #update UI with current CellID
         self.ui.spinBoxCellID.setValue(cellinfo.get_registration_status()[2])
 
@@ -204,6 +205,7 @@ class MyForm(QtGui.QMainWindow):
             try:
                 sub_selected_item = int(sub_selected_item)
             except:
+                QtGui.QMessageBox.information(self, " ", "CellID value has to be integer")
                 continue
 #            print self.cellID_list[selected_item][sub_selected_item]
             if self.cellID_list[selected_item].__contains__(sub_selected_item):
@@ -217,25 +219,11 @@ class MyForm(QtGui.QMainWindow):
                 except: pass
 
     def showTips(self):
-        tipsString = "Choose one of the favorites, enable the alarm and hit 'Go'. As long as the app is running, it will sound an alarm when the phone registers itself with the GSM basestation at the destination.<br>To save the currently registered CellID, just give it a name in the dropdown and hit 'Add CellID'"
+        tipsString = """
+Choose one of the favorites, enable the alarm and hit 'Go'. As long as the app is running, it will sound an alarm when the phone registers itself with the GSM basestation at the destination.<br>To save the currently registered CellID, just give it a name in the dropdown and hit 'Add CellID'
+"""
         #TODO: update tips, change the return method
-
-	self.label = QtGui.QLabel(tipsString)
-        self.label.setWordWrap(True)
-        self.label.setTextFormat(QtCore.Qt.RichText)
-	self.label.setGeometry(QtCore.QRect(0, 0, 700, 400))
-	self.scrollArea = QtGui.QScrollArea(self)
-	self.scrollArea.setWidget(self.label)
-        self.scrollArea.setWidgetResizable(True)
-	self.scrollArea.setGeometry(QtCore.QRect(0, 0, 800, 400))
-        self.scrollArea.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-	self.okButton = QtGui.QPushButton(self.scrollArea)
-        okPosition = QtCore.QRect(700, 350, 100, 50)
-	self.okButton.setGeometry(okPosition)
-	self.okButton.setText("Back")
-        QtCore.QObject.connect(self.okButton, QtCore.SIGNAL('clicked()'), self.closeTips)
-	self.scrollArea.show()
-
+	QtGui.QMessageBox.information(self, "Tips", tipsString)
 
     def showAbout(self):
         aboutString = "Rest in Peace:\nGirish Gopi (rip@gman.me.uk) - version 0.1\nSerhiy Zahoriya (xintx.ua@gmail.com) - version 0.2\nMany thanks to qwerty12, lma, mikec, fatalsaint, Dvortygirl (icon) plus all of t.m.o (& w.m.o)"
